==> google-cloud-sdk-332.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/googlecloudsdk/command_lib/assured/flags.py <==
# -*- coding: utf-8 -*- #
# Copyright 2020 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Flags and helpers for the Assured related commands."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import arg_parsers
from googlecloudsdk.calliope.base import ReleaseTrack
from googlecloudsdk.command_lib.assured import resource_args
from googlecloudsdk.command_lib.util.concepts import concept_parsers

_GA_COMPLIANCE_REGIMES = ['CJIS', 'FEDRAMP_HIGH', 'FEDRAMP_MODERATE', 'IL4']
_BETA_COMPLIANCE_REGIMES = ['CJIS', 'FEDRAMP_HIGH', 'FEDRAMP_MODERATE', 'IL4']

compliance_regimes = {
    ReleaseTrack.GA: _GA_COMPLIANCE_REGIMES,
    ReleaseTrack.BETA: _BETA_COMPLIANCE_REGIMES,
    ReleaseTrack.ALPHA: _BETA_COMPLIANCE_REGIMES
}


def AddListWorkloadsFlags(parser):
  parser.add_argument(
      '--location',
      required=True,
      help=('The location of the Assured Workloads environments. For a '
            'current list of supported LOCATION values, see '
            '[Assured Workloads locations]'
            '(http://cloud/assured-workloads/docs/locations).'))
  parser.add_argument(
      '--organization',
      required=True,
      help=('The parent organization of the Assured Workloads environments, '
            'provided as an organization ID.'))


def AddListOperationsFlags(parser):
  parser.add_argument(
      '--location',
      required=True,
      help=('The location of the Assured Workloads operations. For a '
            'current list of supported LOCATION values, see '
            '[Assured Workloads locations]'
            '(http://cloud/assured-workloads/docs/locations).'))
  parser.add_argument(
      '--organization',
      required=True,
      help=('The parent organization of the Assured Workloads operations, '
            'provided as an organization ID.'))


def AddCreateWorkloadFlags(parser, release_track):
  """Adds required flags to the assured workloads create command.

  Args:
    parser: Parser, Parser used to construct the command flags.
    release_track: ReleaseTrack, Release track of the command being called.

  Returns:
    None.
  """
  parser.add_argument(
      '--location',
      required=True,
      help=('The location of the new Assured Workloads environment. For a '
            'current list of supported LOCATION values, see '
            '[Assured Workloads locations]'
            '(http://cloud/assured-workloads/docs/locations).'))
  parser.add_argument(
      '--organization',
      required=True,
      help=('The parent organization of the new Assured Workloads environment, '
            'provided as an organization ID'))
  parser.add_argument(
      '--external-identifier',
      help='The external identifier of the new Assured Workloads environment')
  parser.add_argument(
      '--display-name',
      required=True,
      help='The display name of the new Assured Workloads environment')
  parser.add_argument(
      '--compliance-regime',
      required=True,
      choices=compliance_regimes.get(release_track),
      help='The compliance regime of the new Assured Workloads environment')
  parser.add_argument(
      '--billing-account',
      required=True,
      help=('The billing account of the new Assured Workloads environment, for '
            'example, billingAccounts/0000AA-AAA00A-A0A0A0'))
  parser.add_argument(
      '--next-rotation-time',
      help=('The next rotation time of the KMS settings of new Assured '
            'Workloads environment, for example, 2020-12-30T10:15:30.00Z'))
  parser.add_argument(
      '--rotation-period',
      help=('The rotation period of the KMS settings of the new Assured '
            'Workloads environment, for example, 172800s'))
  parser.add_argument(
      '--labels',
      type=arg_parsers.ArgDict(),
      metavar='KEY=VALUE',
      help=('The labels of the new Assured Workloads environment, for example, '
            'LabelKey1=LabelValue1,LabelKey2=LabelValue2'))
  parser.add_argument(
      '--provisioned-resources-parent',
      help=('The parent of the provisioned projects, for example, '
            'folders/{FOLDER_ID}'))


def AddDeleteWorkloadFlags(parser):
  AddWorkloadResourceArgToParser(parser, verb='delete')
  parser.add_argument(
      '--etag',
      help=('The etag acquired by reading the Assured Workloads environment or '
            'AW "resource".'))


def AddDescribeWorkloadFlags(parser):
  AddWorkloadResourceArgToParser(parser, verb='describe')


def AddUpdateWorkloadFlags(parser):
  AddWorkloadResourceArgToParser(parser, verb='update')
  parser.add_argument(
      '--etag',
      help=('The etag acquired by reading the Assured Workloads environment '
            'before updating.'))
  updatable_fields = parser.add_group(
      required=True,
      help='Settings that can be updated on the Assured Workloads environment.')
  updatable_fields.add_argument(
      '--display-name',
      help='The new display name of the Assured Workloads environment.')
  updatable_fields.add_argument(
      '--labels',
      metavar='KEY=VALUE',
      type=arg_parsers.ArgDict(),
      help=('The new labels of the Assured Workloads environment, for example, '
            'LabelKey1=LabelValue1,LabelKey2=LabelValue2'))


def AddDescribeOperationFlags(parser):
  concept_parsers.ConceptParser.ForResource(
      'operation',
      resource_args.GetOperationResourceSpec(),
      ('The Assured Workloads operation resource to describe.'),
      required=True).AddToParser(parser)


def AddWorkloadResourceArgToParser(parser, verb):
  concept_parsers.ConceptParser.ForResource(
      'workload',
      resource_args.GetWorkloadResourceSpec(),
      ('The Assured Workloads environment resource to {}.'.format(verb)),
      required=True).AddToParser(parser)

==> google-cloud-sdk-336.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/googlecloudsdk/command_lib/assured/flags.py <==
# -*- coding: utf-8 -*- #
# Copyright 2020 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Flags and helpers for the Assured related commands."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.calliope import arg_parsers
from googlecloudsdk.calliope.base import ReleaseTrack
from googlecloudsdk.command_lib.assured import resource_args
from googlecloudsdk.command_lib.util.concepts import concept_parsers

_GA_COMPLIANCE_REGIMES = [
    'CJIS', 'FEDRAMP_HIGH', 'FEDRAMP_MODERATE', 'IL4', 'US_REGIONAL_ACCESS'
]
_BETA_COMPLIANCE_REGIMES = [
    'CJIS', 'FEDRAMP_HIGH', 'FEDRAMP_MODERATE', 'IL4', 'US_REGIONAL_ACCESS',
    'HIPAA', 'HITRUST'
]

compliance_regimes = {
    ReleaseTrack.GA: _GA_COMPLIANCE_REGIMES,
    ReleaseTrack.BETA: _BETA_COMPLIANCE_REGIMES,
    ReleaseTrack.ALPHA: _BETA_COMPLIANCE_REGIMES
}


def AddListWorkloadsFlags(parser):
  parser.add_argument(
      '--location',
      required=True,
      help=('The location of the Assured Workloads environments. For a '
            'current list of supported LOCATION values, see '
            '[Assured Workloads locations]'
            '(http://cloud/assured-workloads/docs/locations).'))
  parser.add_argument(
      '--organization',
      required=True,
      help=('The parent organization of the Assured Workloads environments, '
            'provided as an organization ID.'))


def AddListOperationsFlags(parser):
  parser.add_argument(
      '--location',
      required=True,
      help=('The location of the Assured Workloads operations. For a '
            'current list of supported LOCATION values, see '
            '[Assured Workloads locations]'
            '(http://cloud/assured-workloads/docs/locations).'))
  parser.add_argument(
      '--organization',
      required=True,
      help=('The parent organization of the Assured Workloads operations, '
            'provided as an organization ID.'))


def AddCreateWorkloadFlags(parser, release_track):
  """Adds required flags to the assured workloads create command.

  Args:
    parser: Parser, Parser used to construct the command flags.
    release_track: ReleaseTrack, Release track of the command being called.

  Returns:
    None.
  """
  parser.add_argument(
      '--location',
      required=True,
      help=('The location of the new Assured Workloads environment. For a '
            'current list of supported LOCATION values, see '
            '[Assured Workloads locations]'
            '(http://cloud/assured-workloads/docs/locations).'))
  parser.add_argument(
      '--organization',
      required=True,
      help=('The parent organization of the new Assured Workloads environment, '
            'provided as an organization ID'))
  parser.add_argument(
      '--external-identifier',
      help='The external identifier of the new Assured Workloads environment')
  parser.add_argument(
      '--display-name',
      required=True,
      help='The display name of the new Assured Workloads environment')
  parser.add_argument(
      '--compliance-regime',
      required=True,
      choices=compliance_regimes.get(release_track),
      help='The compliance regime of the new Assured Workloads environment')
  parser.add_argument(
      '--billing-account',
      required=True,
      help=('The billing account of the new Assured Workloads environment, for '
            'example, billingAccounts/0000AA-AAA00A-A0A0A0'))
  parser.add_argument(
      '--next-rotation-time',
      help=('The next rotation time of the KMS settings of new Assured '
            'Workloads environment, for example, 2020-12-30T10:15:30.00Z'))
  parser.add_argument(
      '--rotation-period',
      help=('The rotation period of the KMS settings of the new Assured '
            'Workloads environment, for example, 172800s'))
  parser.add_argument(
      '--labels',
      type=arg_parsers.ArgDict(),
      metavar='KEY=VALUE',
      help=('The labels of the new Assured Workloads environment, for example, '
            'LabelKey1=LabelValue1,LabelKey2=LabelValue2'))
  parser.add_argument(
      '--provisioned-resources-parent',
      help=('The parent of the provisioned projects, for example, '
            'folders/{FOLDER_ID}'))
  parser.add_argument(
      '--resource-settings',
      type=arg_parsers.ArgDict(spec={
          'consumer-project-id': str,
          'encryption-keys-project-id': str
      }),
      metavar='KEY=VALUE',
      help=(
          'A comma-separated, key=value map of custom resource settings such '
          'as custom project ids, for example: consumer-project-id={CONSUMER_PROJECT_ID} '
          'Note: Currently only consumer-project-id and '
          'encryption-keys-project-id are supported. The '
          'encryption-keys-project-id setting can be specified only if KMS settings '
          'are provided'))


def AddDeleteWorkloadFlags(parser):
  AddWorkloadResourceArgToParser(parser, verb='delete')
  parser.add_argument(
      '--etag',
      help=('The etag acquired by reading the Assured Workloads environment or '
            'AW "resource".'))


def AddDescribeWorkloadFlags(parser):
  AddWorkloadResourceArgToParser(parser, verb='describe')


def AddUpdateWorkloadFlags(parser):
  AddWorkloadResourceArgToParser(parser, verb='update')
  parser.add_argument(
      '--etag',
      help=('The etag acquired by reading the Assured Workloads environment '
            'before updating.'))
  updatable_fields = parser.add_group(
      required=True,
      help='Settings that can be updated on the Assured Workloads environment.')
  updatable_fields.add_argument(
      '--display-name',
      help='The new display name of the Assured Workloads environment.')
  updatable_fields.add_argument(
      '--labels',
      metavar='KEY=VALUE',
      type=arg_parsers.ArgDict(),
      help=('The new labels of the Assured Workloads environment, for example, '
            'LabelKey1=LabelValue1,LabelKey2=LabelValue2'))


def AddDescribeOperationFlags(parser):
  concept_parsers.ConceptParser.ForResource(
      'operation',
      resource_args.GetOperationResourceSpec(),
      ('The Assured Workloads operation resource to describe.'),
      required=True).AddToParser(parser)


def AddWorkloadResourceArgToParser(parser, verb):
  concept_parsers.ConceptParser.ForResource(
      'workload',
      resource_args.GetWorkloadResourceSpec(),
      ('The Assured Workloads environment resource to {}.'.format(verb)),
      required=True).AddToParser(parser)
